@@ -5,16 +5,15 @@ from ._auth import (
     Scheme,
     Role,
     Permission,
-    GrantsMatcher,
-    IMatcher,
-    MatchContext,
 )
+from ._matcher import MatchContext
+from ._parser import PermissionGrantParser, PermissionGrantsParser
 
 __all__ = [
-    "IMatcher",
-    "GrantsMatcher",
     "MatchContext",
     "Permission",
+    "PermissionGrantParser",
+    "PermissionGrantsParser",
     "Resolver",
     "Role",
     "Scheme",
@@ -22,4 +21,4 @@ __all__ = [
 
 __author__ = """Ivan Georgiev"""
 __email__ = "ivan.georgiev@gmail.com"
-__version__ = "0.1.0"
+__version__ = "__version__ = '0.3.0'"
